@@ -10,53 +10,43 @@
 
 #include <QDebug>
 
-
-HotkeysWidgetBase::HotkeysWidgetBase( QWidget *parent )
+HotkeysWidgetBase::HotkeysWidgetBase(QWidget *parent)
     : HotkeysWidgetIFace(parent)
-    {
-    ui.setupUi( this );
-
-    connect(
-        ui.comment, SIGNAL(textChanged()),
-        _changedSignals, SLOT(map()) );
-    _changedSignals->setMapping(ui.comment, "comment" );
-    }
+{
+    ui.setupUi(this);
 
+    connect(ui.comment, SIGNAL(textChanged()), _changedSignals, SLOT(map()));
+    _changedSignals->setMapping(ui.comment, "comment");
+}
 
 HotkeysWidgetBase::~HotkeysWidgetBase()
-    {
-    }
-
+{
+}
 
 void HotkeysWidgetBase::apply()
-    {
+{
     HotkeysWidgetIFace::apply();
     emit changed(_data);
-    }
-
+}
 
 void HotkeysWidgetBase::extend(QWidget *w, const QString &label)
-    {
+{
     ui.tabs->addTab(w, label);
-    }
-
+}
 
 bool HotkeysWidgetBase::isChanged() const
-    {
+{
     return _data->comment() != ui.comment->toPlainText();
-    }
-
+}
 
 void HotkeysWidgetBase::doCopyFromObject()
-    {
-    ui.comment->setText( _data->comment() );
-    }
-
+{
+    ui.comment->setText(_data->comment());
+}
 
 void HotkeysWidgetBase::doCopyToObject()
-    {
-    _data->set_comment( ui.comment->toPlainText() );
-    }
-
+{
+    _data->set_comment(ui.comment->toPlainText());
+}
 
 #include "moc_hotkeys_widget_base.cpp"
